@@ -165,7 +165,7 @@ export_summs <- function(...,
   if (inherits(dots[[1]], 'list')) {
 
     mods <- dots[[1]]
-    if (is.null(model.names) & !is.null(names(mods))) {
+    if (is.null(model.names) && !is.null(names(mods))) {
       model.names <- names(mods)
     }
     if (length(dots) > 1) {
@@ -285,7 +285,7 @@ export_summs <- function(...,
 
       hux_args$note <- note
 
-    } else if (robust == TRUE & scale == FALSE) {
+    } else if (robust == TRUE && scale == FALSE) {
       note <- paste("Standard errors are heteroskedasticity robust. %stars%.")
       hux_args$note <- note
     }
@@ -364,11 +364,8 @@ export_summs <- function(...,
 tidy.summ <- function(x, conf.int = FALSE, conf.level = .95, ...) {
 
   if (all(c("summ.rq", "summ.svyglm") %nin% class(x))) {
-    # Hacky fix for spurious broom warnings with merMod
-    suppressWarnings({
-      base <- generics::tidy(x$model, conf.int = conf.int,
-                            conf.level = conf.level, ...)
-    })
+    base <- generics::tidy(x$model, conf.int = conf.int,
+                          conf.level = conf.level, ...)
   } else if ("summ.rq" %in% class(x)) {
     dots <- list(...)
     dots <- dots[names(dots) %in% c(names(formals("rq")),
@@ -376,8 +373,7 @@ tidy.summ <- function(x, conf.int = FALSE, conf.level = .95, ...) {
                                     "alpha")]
 
     args <- as.list(c(list(x$model), conf.int = conf.int,
-                      conf.level = conf.level,
-                 se.type = attr(x, "se"), dots))
+                      conf.level = conf.level, se.type = attr(x, "se"), dots))
 
     base <- do.call(generics::tidy, args)
   } else {
@@ -411,25 +407,19 @@ tidy.summ <- function(x, conf.int = FALSE, conf.level = .95, ...) {
 
   }
 
-  if ("statistic" %in% names(base) && any(is.na(base[["statistic"]]))) {
-
-    base <- base[!is.na(base$statistic),]
-
-  }
-
   if (attr(x, "exp") == TRUE) {
 
     base$estimate <- x$coeftable[,"exp(Est.)"]
 
   }
 
-  if (attributes(x)$confint == TRUE | conf.int == TRUE) {
+  if (attributes(x)$confint == TRUE || conf.int == TRUE) {
 
     labs <- make_ci_labs(conf.level)
     lci_lab <- labs$lci
     uci_lab <- labs$uci
 
-    if (attributes(x)$confint == TRUE & attributes(x)$ci.width == conf.level) {
+    if (attributes(x)$confint == TRUE && attributes(x)$ci.width == conf.level) {
       base$conf.low <- x$coeftable[,lci_lab]
       base$conf.high <- x$coeftable[,uci_lab]
     } else {
@@ -455,6 +445,17 @@ tidy.summ <- function(x, conf.int = FALSE, conf.level = .95, ...) {
     }
 
   }
+  
+  if (attr(x, "vifs") == TRUE) {
+    base$vif <- x$coeftable[,"VIF"]
+  }
+  
+  # Moved later to avoid errors when there are undefined coefficients
+  if ("statistic" %in% names(base) && any(is.na(base[["statistic"]]))) {
+    
+    base <- base[!is.na(base$statistic),]
+    
+  }
 
   num_cols <- sapply(base, is.numeric)
   zeroes <- check_if_zero(base[num_cols])
@@ -468,6 +469,100 @@ tidy.summ <- function(x, conf.int = FALSE, conf.level = .95, ...) {
 
 }
 
+#' @rdname glance.summ
+#' @rawNamespace 
+#' if (getRversion() >= "3.6.0") {
+#'  S3method(generics::tidy, summ.merMod)
+#' } else {
+#'  export(tidy.summ.merMod)
+#' }
+
+tidy.summ.merMod <- function(x, conf.int = FALSE, conf.level = .95, ...) {
+
+  base <- generics::tidy(x$model, conf.int = conf.int,
+                         conf.level = conf.level, ...)
+  
+  # Deleting random effects
+  if ("statistic" %in% names(base) && any(is.na(base[["statistic"]]))) {
+    base <- base[!is.na(base$statistic),]
+  }
+  
+  if ("S.E." %in% colnames(x$coeftable)) {
+    # If conf.int == TRUE, summ does not have a S.E. column
+    base$std.error[!is.na(base$std.error)] <- x$coeftable[,"S.E."]
+    
+  }
+  
+  # Need to find the statistic column without knowing what it will be called
+  stat_col <- attributes(x)$test.stat
+  
+  # Filtering to not NA avoids issues with NAs being filled with
+  # repetitive values due to replacement being multiple of its length
+  if ("statistic" %in% names(base)) {
+    base$statistic[!is.na(base$statistic)] <- x$coeftable[,stat_col]
+  }
+  
+  if ("p" %in% colnames(x$coeftable)) {
+    
+    base[["p.value"]][!is.na(base$statistic)] <- x$coeftable[,"p"]
+    
+  } else if (!("p.value" %in% names(base))) {
+    
+    base[["p.value"]] <- NA
+    
+  }
+  
+  if (attr(x, "exp") == TRUE) {
+    
+    base$estimate <- x$coeftable[,"exp(Est.)"]
+    
+  }
+  
+  if (attributes(x)$confint == TRUE || conf.int == TRUE) {
+    
+    labs <- make_ci_labs(conf.level)
+    lci_lab <- labs$lci
+    uci_lab <- labs$uci
+    
+    if (attributes(x)$confint == TRUE && attributes(x)$ci.width == conf.level) {
+      base$conf.low <- x$coeftable[,lci_lab]
+      base$conf.high <- x$coeftable[,uci_lab]
+    } else {
+      conf.level <- as.numeric(deparse(conf.level))
+      e <- environment()
+      x <- update_summ(x, confint = TRUE, ci.width = conf.level, call.env = e)
+      base$conf.low <- x$coeftable[,lci_lab]
+      base$conf.high <- x$coeftable[,uci_lab]
+    }
+    
+  }
+  
+  if (!is.null(attr(x, "coef_export"))) {
+    
+    the_coefs <- attr(x, "coef_export")
+    base <- base[base$term %in% the_coefs,]
+    if (!is.null(names(the_coefs))) {
+      for (i in seq_along(the_coefs)) {
+        if (names(the_coefs[i]) != "") {
+          base$term[base$term == the_coefs[i]] <- names(the_coefs[i])
+        }
+      }
+    }
+    
+  }
+  
+  num_cols <- sapply(base, is.numeric)
+  zeroes <- check_if_zero(base[num_cols])
+  if (any(zeroes == TRUE)) {
+    basenums <- base[num_cols]
+    basenums[zeroes] <- 0
+    base[num_cols] <- basenums
+  }
+  
+  return(base)
+  
+}
+
 #' @title Broom extensions for summ objects
 #' @description These are functions used for compatibility with broom's tidying
 #' functions to facilitate use with huxreg, thereby making
