@@ -2,14 +2,14 @@
 required <- c("survey", "huxtable", "broom", "lme4", "quantreg")
 if (!all(sapply(required, requireNamespace, quietly = TRUE)))
   knitr::opts_chunk$set(eval = FALSE)
-knitr::opts_chunk$set(message = F, warning = F, fig.width = 6, fig.height = 4,
-                      dpi = 100, render = knitr::normal_print)
+knitr::opts_chunk$set(message = FALSE, warning = FALSE, fig.width = 6, 
+                      fig.height = 4, dpi = 125, render = knitr::normal_print)
 library(jtools)
 
 ## -----------------------------------------------------------------------------
-# Fit model
-states <- as.data.frame(state.x77)
-fit <- lm(Income ~ Frost + Illiteracy + Murder, data = states)
+library(jtools) # Load jtools
+data(movies) # Telling R we want to use this data
+fit <- lm(metascore ~ imdb_rating + log(us_gross) + genre5, data = movies)
 summ(fit)
 
 ## ----render = 'knit_print'----------------------------------------------------
@@ -37,7 +37,8 @@ summ(fit, confint = TRUE, ci.width = .5)
 summ(fit, confint = TRUE, pvals = FALSE)
 
 ## -----------------------------------------------------------------------------
-fitg <- glm(vs ~ drat + mpg, data = mtcars, family = binomial)
+fitg <- glm(metascore/100 ~ imdb_rating + log(us_gross) + genre5, data = movies,
+            family = quasibinomial())
 
 summ(fitg)
 
@@ -51,31 +52,32 @@ fm1 <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
 summ(fm1)
 
 ## -----------------------------------------------------------------------------
-effect_plot(fit, pred = Illiteracy, interval = TRUE, plot.points = TRUE)
+effect_plot(fitg, pred = imdb_rating, interval = TRUE, plot.points = TRUE, 
+            jitter = 0.05)
 
 ## -----------------------------------------------------------------------------
 plot_summs(fit)
 
 ## -----------------------------------------------------------------------------
-plot_summs(fit, scale = TRUE)
+plot_summs(fit, robust = TRUE)
 
 ## -----------------------------------------------------------------------------
-plot_summs(fit, scale = TRUE, inner_ci_level = .9)
+plot_summs(fit, inner_ci_level = .9)
 
 ## -----------------------------------------------------------------------------
-plot_summs(fit, scale = TRUE, plot.distributions = TRUE, inner_ci_level = .9)
+plot_summs(fit, plot.distributions = TRUE, inner_ci_level = .9)
 
 ## -----------------------------------------------------------------------------
-fit2 <- lm(Income ~ Frost + Illiteracy + Murder + `HS Grad`,
-           data = states)
-plot_summs(fit, fit2, scale = TRUE)
+fit2 <- lm(metascore ~ imdb_rating + log(us_gross) + log(budget) + genre5,
+           data = movies)
+plot_summs(fit, fit2)
 
 ## -----------------------------------------------------------------------------
-plot_summs(fit, fit2, scale = TRUE, plot.distributions = TRUE)
+plot_summs(fit, fit2, plot.distributions = TRUE)
 
 ## -----------------------------------------------------------------------------
-plot_summs(fit, fit, fit, scale = TRUE, robust = list(FALSE, "HC0", "HC3"),
-           model.names = c("OLS", "HC0", "HC3"))
+plot_summs(fit, fit, fit, robust = list(FALSE, "HC0", "HC5"),
+           model.names = c("OLS", "HC0", "HC5"))
 
 ## ----eval = FALSE-------------------------------------------------------------
 #  export_summs(fit, fit2, scale = TRUE)
